@@ -9,6 +9,7 @@ app = Typer(
     help="Tool to handle a large number of beamer decks, "
     "used by several persons, with shared slides amongst the decks.",
     chain=True,
+    pretty_exceptions_show_locals=False,
 )
 
 
@@ -17,7 +18,7 @@ def main() -> None:
         level=INFO,
         format="%(message)s",
         datefmt="%H:%M:%S",
-        handlers=[RichHandler(rich_tracebacks=True)],
+        handlers=[RichHandler(rich_tracebacks=True, tracebacks_show_locals=False)],
     )
     import_module_and_submodules(__name__)
     app()
